{ pkgs, ... }:
{
  programs.mtr.enable = true;
  programs.mosh.enable = true;
  programs.tmux.enable = true;
  programs.wireshark.enable = true;

  environment.systemPackages = with pkgs; [
    kitty
    # Todolist
    taskwarrior

    # Slicers
    prusa-slicer super-slicer

    # CAD/3D
    blender freecad openscad kicad-with-packages3d
    # Microcontrollers
    arduino arduino-cli stm32flash stm32loader
    # FPGA
    # python38Packages.nmigen python38Packages.nmigen-soc python38Packages.nmigen-boards
    verilog verilator yosys symbiyosys mcy
    # Reverse engineering
    ghidra-bin apktool pwndbg
    radare2

    # IRC
    weechat

    # Editors
    vscodium emacs neovim

    # Utilities
    minicom
    smartmontools
    starship
    wget firefox ripgrep chromium
    nmap
    htop
    dnsutils
    ncdu lazygit

    # Networking
    speedtest-cli iperf

    # CNC
    inkscape
  ];

  programs.chromium = {
    enable = true;

    extensions = [
      "cjpalhdlnbpafiamejdnhcphjbkeiagm" # uBlock Origin
      "gcbommkclmclpchllfjekcdonpmejbdp" # HTTPS Everywhere
      "mbniclmhobmnbdlbpiphghaielnnpgdp" # Lightshot
      "ldlghkoiihaelfnggonhjnfiabmaficg" # QuicKey
    ];

    homepageLocation = "https://hackens.org";

    extraOpts = {
      "BrowserSignin" = 0;
      "SyncDisabled" = true;
      "PasswordManagerEnabled" = false;
      "SafeBrowsingEnabled" = false;
      "AdvancedProtectionAllowed" = false;
      "BrowserGuestModeEnabled" = true;
      "SpellcheckEnabled" = true;
      "NewTabPageLocation" = "https://hackens.org";
      "SpellcheckLanguage" = [
        "fr-FR"
        "en-US"
      ];
    };
  };
}
